@@ -185,7 +185,7 @@ daap_share_message_add_standard_headers (DMAPShare * share,
 					 SoupMessage * message)
 {
 	soup_message_headers_append (message->response_headers, "DMAP-Server",
-				     "libdmapsharing" VERSION);
+				     "libdmapsharing" "VERSION");
 }
 
 #define DMAP_VERSION 2.0
@@ -398,7 +398,7 @@ static gboolean should_transcode (const gchar *format, const gboolean has_video,
 	}
 
 done:
-	g_debug ("    Should%s transcode %s %s", fnval ? "" : " not", format, format2 ? format2 : "[no target format]");
+	g_debug ("    Should%s transcode %s to %s", fnval ? "" : " not", format, format2 ? format2 : "[no target format]");
 
 	return fnval;
 }
@@ -922,7 +922,7 @@ databases_items_xxx (DMAPShare * share,
 		const gchar *s;
 		gchar *content_range;
 
-		if (!g_ascii_strncasecmp (range_header, "bytes=", strlen("bytes="))) {
+		if (!g_str_has_prefix (range_header, "bytes=")) {
 			/* Not starting with "bytes=" ? */
 			offset = 0;
 		} else {
