@@ -19,7 +19,7 @@
  */
 
 #include "dmap-structure.h"
-#include "dmap-utils.h"
+#include "dmap-private-utils.h"
 
 #include <glib.h>
 #include <glib-object.h>
@@ -412,7 +412,7 @@ dmap_structure_node_serialize (GNode * node, GByteArray * array)
 	switch (dmap_type) {
 	case DMAP_TYPE_BYTE:
 	case DMAP_TYPE_SIGNED_INT:{
-			gchar c = g_value_get_char (&(item->content));
+			gchar c = g_value_get_schar (&(item->content));
 
 			g_byte_array_append (array, (const guint8 *) &c, 1);
 
@@ -552,7 +552,7 @@ dmap_structure_parse_container_buffer (GNode * parent,
 
 		/* we need at least 8 bytes, 4 of content_code and 4 of size */
 		if (buf_length - l < 8) {
-			g_debug ("Malformed response recieved\n");
+			g_debug ("Malformed response received\n");
 			return;
 		}
 
@@ -571,7 +571,7 @@ dmap_structure_parse_container_buffer (GNode * parent,
 		 * then get out before we start processing it
 		 */
 		if (codesize > buf_length - l - 4 || codesize < 0) {
-			g_debug ("Invalid codesize %d recieved in buf_length %d\n", codesize, buf_length);
+			g_debug ("Invalid codesize %d received in buf_length %d\n", codesize, buf_length);
 			return;
 		}
 		l += 4;
@@ -598,7 +598,7 @@ dmap_structure_parse_container_buffer (GNode * parent,
 				}
 
 				item->size = 1;
-				g_value_set_char (&(item->content), c);
+				g_value_set_schar (&(item->content), c);
 				break;
 			}
 		case DMAP_TYPE_SHORT:{
